@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,6 @@
 #include <KMime/Message>
 
 #include <KIconEffect>
-#include <KIconLoader>
 #include <QEvent>
 #include <QMouseEvent>
 #include <QToolTip>
@@ -37,9 +36,7 @@ KNotesIconView::KNotesIconView(KNotesPart *part, QWidget *parent)
     setMouseTracking(true);
 }
 
-KNotesIconView::~KNotesIconView()
-{
-}
+KNotesIconView::~KNotesIconView() = default;
 
 bool KNotesIconView::event(QEvent *e)
 {
@@ -68,7 +65,11 @@ void KNotesIconView::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton) {
         QListView::mousePressEvent(e);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m_part->popupRMB(currentItem(), e->pos(), e->globalPos());
+#else
+        m_part->popupRMB(currentItem(), e->pos(), e->globalPosition().toPoint());
+#endif
     } else {
         QListView::mousePressEvent(e);
     }
@@ -174,7 +175,7 @@ void KNotesIconViewItem::setChangeIconTextAndDescription(const QString &iconText
 void KNotesIconViewItem::setIconText(const QString &text, bool save)
 {
     QString replaceText;
-    if (text.count() > 50) {
+    if (text.length() > 50) {
         replaceText = text.left(50) + QLatin1String("...");
     } else {
         replaceText = text;
@@ -312,7 +313,7 @@ void KNotesIconViewItem::updateSettings()
     KIconEffect effect;
     const QColor color(mDisplayAttribute->backgroundColor());
     if (mDefaultPixmap.isNull()) {
-        mDefaultPixmap = KIconLoader::global()->loadIcon(QStringLiteral("knotes"), KIconLoader::Desktop);
+        mDefaultPixmap = QIcon::fromTheme(QStringLiteral("knotes")).pixmap(48);
     }
     QPixmap icon = effect.apply(mDefaultPixmap, KIconEffect::Colorize, 1, color, false);
     setFont(mDisplayAttribute->titleFont());
